@@ -15,7 +15,9 @@ OPENTELEMETRY_BEGIN_NAMESPACE
 namespace logs
 {
 
+#if OPENTELEMETRY_ABI_VERSION_NO < 2
 class EventLoggerProvider;
+#endif
 class LoggerProvider;
 
 /**
@@ -45,13 +47,15 @@ public:
     GetProvider() = tp;
   }
 
+#if OPENTELEMETRY_ABI_VERSION_NO < 2
   /**
    * Returns the singleton EventLoggerProvider.
    *
    * By default, a no-op EventLoggerProvider is returned. This will never return a
    * nullptr EventLoggerProvider.
    */
-  static nostd::shared_ptr<EventLoggerProvider> GetEventLoggerProvider() noexcept
+  OPENTELEMETRY_DEPRECATED static nostd::shared_ptr<EventLoggerProvider>
+  GetEventLoggerProvider() noexcept
   {
     std::lock_guard<common::SpinLockMutex> guard(GetLock());
     return nostd::shared_ptr<EventLoggerProvider>(GetEventProvider());
@@ -60,11 +64,13 @@ public:
   /**
    * Changes the singleton EventLoggerProvider.
    */
-  static void SetEventLoggerProvider(const nostd::shared_ptr<EventLoggerProvider> &tp) noexcept
+  OPENTELEMETRY_DEPRECATED static void SetEventLoggerProvider(
+      const nostd::shared_ptr<EventLoggerProvider> &tp) noexcept
   {
     std::lock_guard<common::SpinLockMutex> guard(GetLock());
     GetEventProvider() = tp;
   }
+#endif
 
 private:
   OPENTELEMETRY_API_SINGLETON static nostd::shared_ptr<LoggerProvider> &GetProvider() noexcept
@@ -73,12 +79,15 @@ private:
     return provider;
   }
 
+#if OPENTELEMETRY_ABI_VERSION_NO < 2
+  OPENTELEMETRY_DEPRECATED
   OPENTELEMETRY_API_SINGLETON static nostd::shared_ptr<EventLoggerProvider> &
   GetEventProvider() noexcept
   {
     static nostd::shared_ptr<EventLoggerProvider> provider(new NoopEventLoggerProvider);
     return provider;
   }
+#endif
 
   OPENTELEMETRY_API_SINGLETON static common::SpinLockMutex &GetLock() noexcept
   {
