@@ -5,16 +5,18 @@
 #include <string>
 
 #include "opentelemetry/common/key_value_iterable.h"
-#include "opentelemetry/logs/event_logger.h"  // IWYU pragma: keep
-#include "opentelemetry/logs/event_logger_provider.h"
-#include "opentelemetry/logs/logger.h"  // IWYU pragma: keep
+#include "opentelemetry/logs/event_logger.h"           // IWYU pragma: keep
+#include "opentelemetry/logs/event_logger_provider.h"  // IWYU pragma: keep
+#include "opentelemetry/logs/logger.h"                 // IWYU pragma: keep
 #include "opentelemetry/logs/logger_provider.h"
 #include "opentelemetry/logs/provider.h"
 #include "opentelemetry/nostd/shared_ptr.h"
 #include "opentelemetry/nostd/string_view.h"
 
+#if OPENTELEMETRY_ABI_VERSION_NO < 2
 using opentelemetry::logs::EventLogger;
 using opentelemetry::logs::EventLoggerProvider;
+#endif
 using opentelemetry::logs::Logger;
 using opentelemetry::logs::LoggerProvider;
 using opentelemetry::logs::Provider;
@@ -71,6 +73,7 @@ TEST(Provider, GetLogger)
   EXPECT_EQ(nullptr, logger2);
 }
 
+#if OPENTELEMETRY_ABI_VERSION_NO < 2
 class TestEventLoggerProvider : public EventLoggerProvider
 {
 public:
@@ -112,3 +115,4 @@ TEST(Provider, CreateEventLogger)
 
   EXPECT_EQ(nullptr, logger);
 }
+#endif
