@@ -3,21 +3,39 @@
 
 #pragma once
 
-#include "opentelemetry/exporters/otlp/protobuf_include_prefix.h"
-
-#include "opentelemetry/proto/collector/logs/v1/logs_service.pb.h"
-#include "opentelemetry/proto/collector/trace/v1/trace_service.pb.h"
-
-#include "opentelemetry/exporters/otlp/protobuf_include_suffix.h"
-
-#include "opentelemetry/sdk/trace/recordable.h"
-
-#ifdef ENABLE_LOGS_PREVIEW
-#  include "opentelemetry/sdk/logs/recordable.h"
-#endif
-
 #include <memory>
 
+#include "opentelemetry/nostd/span.h"
+#include "opentelemetry/sdk/logs/recordable.h"
+#include "opentelemetry/sdk/trace/recordable.h"
+#include "opentelemetry/version.h"
+
+namespace opentelemetry
+{
+namespace proto
+{
+namespace collector
+{
+
+namespace logs
+{
+namespace v1
+{
+class ExportLogsServiceRequest;
+}
+}  // namespace logs
+namespace trace
+{
+namespace v1
+{
+class ExportTraceServiceRequest;
+}
+}  // namespace trace
+
+}  // namespace collector
+}  // namespace proto
+}  // namespace opentelemetry
+
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace exporter
 {
@@ -33,11 +51,9 @@ public:
       const nostd::span<std::unique_ptr<opentelemetry::sdk::trace::Recordable>> &spans,
       proto::collector::trace::v1::ExportTraceServiceRequest *request) noexcept;
 
-#ifdef ENABLE_LOGS_PREVIEW
   static void PopulateRequest(
       const nostd::span<std::unique_ptr<opentelemetry::sdk::logs::Recordable>> &logs,
       proto::collector::logs::v1::ExportLogsServiceRequest *request) noexcept;
-#endif
 };
 }  // namespace otlp
 }  // namespace exporter
