@@ -1,9 +1,34 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
+#include <gtest/gtest.h>
+#include <chrono>
+#include <cstdint>
+#include <cstring>
+#include <map>
+#include <string>
+#include <utility>
+#include <vector>
+
+#include "opentelemetry/common/attribute_value.h"
+#include "opentelemetry/common/key_value_iterable_view.h"
+#include "opentelemetry/common/timestamp.h"
 #include "opentelemetry/exporters/otlp/otlp_recordable.h"
 #include "opentelemetry/exporters/otlp/otlp_recordable_utils.h"
+#include "opentelemetry/nostd/shared_ptr.h"
+#include "opentelemetry/nostd/span.h"
+#include "opentelemetry/nostd/string_view.h"
+#include "opentelemetry/nostd/variant.h"
+#include "opentelemetry/sdk/instrumentationscope/instrumentation_scope.h"
 #include "opentelemetry/sdk/resource/resource.h"
+#include "opentelemetry/sdk/trace/recordable.h"
+#include "opentelemetry/trace/span_context.h"
+#include "opentelemetry/trace/span_id.h"
+#include "opentelemetry/trace/span_metadata.h"
+#include "opentelemetry/trace/trace_flags.h"
+#include "opentelemetry/trace/trace_id.h"
+#include "opentelemetry/trace/trace_state.h"
+#include "opentelemetry/version.h"
 
 #if defined(__GNUC__)
 // GCC raises -Wsuggest-override warnings on GTest,
@@ -11,11 +36,13 @@
 #  pragma GCC diagnostic ignored "-Wsuggest-override"
 #endif
 
-#include <gtest/gtest.h>
-
 // clang-format off
 #include "opentelemetry/exporters/otlp/protobuf_include_prefix.h" // IWYU pragma: keep
+// IWYU pragma: no_include "net/proto2/public/repeated_field.h"
 #include "opentelemetry/proto/collector/trace/v1/trace_service.pb.h"
+#include "opentelemetry/proto/common/v1/common.pb.h"
+#include "opentelemetry/proto/resource/v1/resource.pb.h"
+#include "opentelemetry/proto/trace/v1/trace.pb.h"
 #include "opentelemetry/exporters/otlp/protobuf_include_suffix.h" // IWYU pragma: keep
 // clang-format on
 
@@ -93,6 +120,29 @@ TEST(OtlpRecordable, SetInstrumentationLibraryWithSchemaURL)
   EXPECT_EQ(expected_schema_url, rec.GetInstrumentationLibrarySchemaURL());
 }
 
+TEST(OtlpRecordable, SetInstrumentationScopeWithAttributes)
+{
+  exporter::otlp::OtlpRecordable rec;
+
+  auto inst_lib = trace_sdk::InstrumentationScope::Create(
+      "test_scope_name", "test_version", "test_schema_url", {{"test_key", "test_value"}});
+
+  ASSERT_EQ(inst_lib->GetAttributes().size(), 1);
+
+  rec.SetInstrumentationScope(*inst_lib);
+
+  const auto proto_instr_libr = rec.GetProtoInstrumentationScope();
+  EXPECT_EQ("test_scope_name", proto_instr_libr.name());
+  EXPECT_EQ("test_version", proto_instr_libr.version());
+
+  ASSERT_EQ(proto_instr_libr.attributes_size(), 1);
+  const auto &proto_attributes = proto_instr_libr.attributes(0);
+  // Requires protoc 3.15.0
+  // ASSERT_TRUE(proto_attributes.value().has_string_value());
+  EXPECT_EQ("test_key", proto_attributes.key());
+  EXPECT_EQ("test_value", proto_attributes.value().string_value());
+}
+
 TEST(OtlpRecordable, SetStartTime)
 {
   OtlpRecordable rec;
@@ -207,22 +257,98 @@ TEST(OtlpRecordable, AddLink)
 TEST(OtlpRecordable, SetResource)
 {
   OtlpRecordable rec;
-  const std::string service_name_key = "service.name";
-  std::string service_name           = "test-otlp";
-  auto resource = resource::Resource::Create({{service_name_key, service_name}});
+  bool array_bool[]                                = {true, false, true};
+  int32_t array_int[]                              = {1, 2, 3};
+  double array_double[]                            = {1.1, 2.2, 3.3};
+  opentelemetry::nostd::string_view array_string[] = {"str1", "str2", "str3"};
+
+  resource::ResourceAttributes attributes{
+      {"service.name", opentelemetry::nostd::string_view{"test-otlp"}},
+      {"bool_value", true},
+      {"int_value", 3},
+      {"double_value", static_cast<double>(1.4)},
+      {"bytes_value",
+       opentelemetry::nostd::span<const uint8_t>{reinterpret_cast<const uint8_t *>("\1\0\3abc"),
+                                                 6}},
+      {"bool_array", opentelemetry::nostd::span<const bool>{array_bool}},
+      {"int_array", opentelemetry::nostd::span<const int32_t>{array_int}},
+      {"double_array", opentelemetry::nostd::span<const double>{array_double}},
+      {"string_array",
+       opentelemetry::nostd::span<const opentelemetry::nostd::string_view>{array_string}}};
+
+  auto resource = resource::Resource::Create(attributes);
   rec.SetResource(resource);
 
-  auto proto_resource     = rec.ProtoResource();
-  bool found_service_name = false;
+  auto proto_resource          = rec.ProtoResource();
+  size_t found_attribute_count = 0;
   for (int i = 0; i < proto_resource.attributes_size(); i++)
   {
     const auto &attr = proto_resource.attributes(static_cast<int>(i));
-    if (attr.key() == service_name_key && attr.value().string_value() == service_name)
+    if (attr.key() == "service.name")
     {
-      found_service_name = true;
+      EXPECT_EQ(attr.value().string_value(), std::string{"test-otlp"});
+      ++found_attribute_count;
+    }
+    else if (attr.key() == "bool_value")
+    {
+      EXPECT_EQ(attr.value().bool_value(), true);
+      ++found_attribute_count;
+    }
+    else if (attr.key() == "int_value")
+    {
+      EXPECT_EQ(attr.value().int_value(), 3);
+      ++found_attribute_count;
+    }
+    else if (attr.key() == "double_value")
+    {
+      EXPECT_EQ(attr.value().double_value(), static_cast<double>(1.4));
+      ++found_attribute_count;
+    }
+    else if (attr.key() == "bytes_value")
+    {
+      EXPECT_EQ(attr.value().array_value().values_size(), 6);
+      EXPECT_EQ(attr.value().array_value().values(0).int_value(), 1);
+      EXPECT_EQ(attr.value().array_value().values(1).int_value(), 0);
+      EXPECT_EQ(attr.value().array_value().values(2).int_value(), 3);
+      EXPECT_EQ(attr.value().array_value().values(3).int_value(), static_cast<int>('a'));
+      EXPECT_EQ(attr.value().array_value().values(4).int_value(), static_cast<int>('b'));
+      EXPECT_EQ(attr.value().array_value().values(5).int_value(), static_cast<int>('c'));
+      ++found_attribute_count;
+    }
+    else if (attr.key() == "bool_array")
+    {
+      EXPECT_EQ(attr.value().array_value().values_size(), 3);
+      EXPECT_EQ(attr.value().array_value().values(0).bool_value(), true);
+      EXPECT_EQ(attr.value().array_value().values(1).bool_value(), false);
+      EXPECT_EQ(attr.value().array_value().values(2).bool_value(), true);
+      ++found_attribute_count;
+    }
+    else if (attr.key() == "int_array")
+    {
+      EXPECT_EQ(attr.value().array_value().values_size(), 3);
+      EXPECT_EQ(attr.value().array_value().values(0).int_value(), 1);
+      EXPECT_EQ(attr.value().array_value().values(1).int_value(), 2);
+      EXPECT_EQ(attr.value().array_value().values(2).int_value(), 3);
+      ++found_attribute_count;
+    }
+    else if (attr.key() == "double_array")
+    {
+      EXPECT_EQ(attr.value().array_value().values_size(), 3);
+      EXPECT_EQ(attr.value().array_value().values(0).double_value(), 1.1);
+      EXPECT_EQ(attr.value().array_value().values(1).double_value(), 2.2);
+      EXPECT_EQ(attr.value().array_value().values(2).double_value(), 3.3);
+      ++found_attribute_count;
+    }
+    else if (attr.key() == "string_array")
+    {
+      EXPECT_EQ(attr.value().array_value().values_size(), 3);
+      EXPECT_EQ(attr.value().array_value().values(0).string_value(), "str1");
+      EXPECT_EQ(attr.value().array_value().values(1).string_value(), "str2");
+      EXPECT_EQ(attr.value().array_value().values(2).string_value(), "str3");
+      ++found_attribute_count;
     }
   }
-  EXPECT_TRUE(found_service_name);
+  EXPECT_EQ(found_attribute_count, attributes.size());
 }
 
 TEST(OtlpRecordable, SetResourceWithSchemaURL)
@@ -254,6 +380,12 @@ TEST(OtlpRecordable, SetSingleAttribute)
   common::AttributeValue str_val(nostd::string_view("Test"));
   rec.SetAttribute(str_key, str_val);
 
+  nostd::string_view byte_key = "byte_attr";
+  uint8_t byte_arr[]          = {'T', 'e', 's', 't'};
+  common::AttributeValue byte_val(
+      nostd::span<const uint8_t>{reinterpret_cast<const uint8_t *>(byte_arr), 4});
+  rec.SetAttribute(byte_key, byte_val);
+
   EXPECT_EQ(rec.span().attributes(0).key(), bool_key);
   EXPECT_EQ(rec.span().attributes(0).value().bool_value(), nostd::get<bool>(bool_val));
 
@@ -263,6 +395,17 @@ TEST(OtlpRecordable, SetSingleAttribute)
   EXPECT_EQ(rec.span().attributes(2).key(), str_key);
   EXPECT_EQ(rec.span().attributes(2).value().string_value(),
             nostd::get<nostd::string_view>(str_val).data());
+
+  EXPECT_EQ(rec.span().attributes(3).key(), byte_key);
+  EXPECT_EQ(rec.span().attributes(3).value().array_value().values_size(), 4);
+  EXPECT_EQ(rec.span().attributes(3).value().array_value().values(0).int_value(),
+            static_cast<int>('T'));
+  EXPECT_EQ(rec.span().attributes(3).value().array_value().values(1).int_value(),
+            static_cast<int>('e'));
+  EXPECT_EQ(rec.span().attributes(3).value().array_value().values(2).int_value(),
+            static_cast<int>('s'));
+  EXPECT_EQ(rec.span().attributes(3).value().array_value().values(3).int_value(),
+            static_cast<int>('t'));
 }
 
 // Test non-int array types. Int array types are tested using templates (see IntAttributeTest)
@@ -298,7 +441,8 @@ TEST(OtlpRecordable, PopulateRequest)
   auto rec1      = std::unique_ptr<sdk::trace::Recordable>(new OtlpRecordable);
   auto resource1 = resource::Resource::Create({{"service.name", "one"}});
   rec1->SetResource(resource1);
-  auto inst_lib1 = trace_sdk::InstrumentationScope::Create("one", "1");
+  auto inst_lib1 = trace_sdk::InstrumentationScope::Create("one", "1", "scope_schema",
+                                                           {{"scope_key", "scope_value"}});
   rec1->SetInstrumentationScope(*inst_lib1);
 
   auto rec2      = std::unique_ptr<sdk::trace::Recordable>(new OtlpRecordable);
@@ -324,12 +468,23 @@ TEST(OtlpRecordable, PopulateRequest)
   EXPECT_EQ(req.resource_spans().size(), 2);
   for (const auto &resource_spans : req.resource_spans())
   {
-    auto service_name     = resource_spans.resource().attributes(0).value().string_value();
-    auto scope_spans_size = resource_spans.scope_spans().size();
+    ASSERT_GT(resource_spans.resource().attributes_size(), 0);
+    const auto service_name     = resource_spans.resource().attributes(0).value().string_value();
+    const auto scope_spans_size = resource_spans.scope_spans().size();
     if (service_name == "one")
     {
+      ASSERT_GT(resource_spans.scope_spans_size(), 0);
+      const auto &scope_one = resource_spans.scope_spans(0).scope();
+
       EXPECT_EQ(scope_spans_size, 1);
-      EXPECT_EQ(resource_spans.scope_spans(0).scope().name(), "one");
+      EXPECT_EQ(scope_one.name(), "one");
+      EXPECT_EQ(scope_one.version(), "1");
+
+      ASSERT_EQ(scope_one.attributes_size(), 1);
+      const auto &scope_attribute = scope_one.attributes(0);
+
+      EXPECT_EQ(scope_attribute.key(), "scope_key");
+      EXPECT_EQ(scope_attribute.value().string_value(), "scope_value");
     }
     if (service_name == "two")
     {
