@@ -3,9 +3,12 @@
 
 #pragma once
 
-#include <memory>
+#if OPENTELEMETRY_ABI_VERSION_NO < 2
+#  include <memory>
+
+#  include "opentelemetry/sdk/logs/event_logger_provider.h"
+#endif
 
-#include "opentelemetry/sdk/logs/event_logger_provider.h"
 #include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
@@ -14,18 +17,21 @@ namespace sdk
 namespace logs
 {
 
+#if OPENTELEMETRY_ABI_VERSION_NO < 2
 /**
  * Factory class for EventLoggerProvider.
  */
-class EventLoggerProviderFactory
+class OPENTELEMETRY_DEPRECATED EventLoggerProviderFactory
 {
 public:
   /**
    * Create a EventLoggerProvider.
    */
 
-  static std::unique_ptr<opentelemetry::sdk::logs::EventLoggerProvider> Create();
+  OPENTELEMETRY_DEPRECATED static std::unique_ptr<opentelemetry::sdk::logs::EventLoggerProvider>
+  Create();
 };
+#endif
 
 }  // namespace logs
 }  // namespace sdk
