@@ -7,6 +7,7 @@
 #include "opentelemetry/sdk/logs/batch_log_record_processor.h"
 #include "opentelemetry/sdk/logs/batch_log_record_processor_factory.h"
 #include "opentelemetry/sdk/logs/batch_log_record_processor_options.h"
+#include "opentelemetry/sdk/logs/batch_log_record_processor_runtime_options.h"
 #include "opentelemetry/sdk/logs/exporter.h"
 #include "opentelemetry/sdk/logs/processor.h"
 #include "opentelemetry/version.h"
@@ -20,9 +21,18 @@ namespace logs
 std::unique_ptr<LogRecordProcessor> BatchLogRecordProcessorFactory::Create(
     std::unique_ptr<LogRecordExporter> &&exporter,
     const BatchLogRecordProcessorOptions &options)
+{
+  BatchLogRecordProcessorRuntimeOptions runtime_options;
+  return Create(std::move(exporter), options, runtime_options);
+}
+
+std::unique_ptr<LogRecordProcessor> BatchLogRecordProcessorFactory::Create(
+    std::unique_ptr<LogRecordExporter> &&exporter,
+    const BatchLogRecordProcessorOptions &options,
+    const BatchLogRecordProcessorRuntimeOptions &runtime_options)
 {
   std::unique_ptr<LogRecordProcessor> processor(
-      new BatchLogRecordProcessor(std::move(exporter), options));
+      new BatchLogRecordProcessor(std::move(exporter), options, runtime_options));
   return processor;
 }
 
