@@ -4,6 +4,8 @@
 #include <benchmark/benchmark.h>
 #include <map>
 #include <string>
+#include <unordered_map>
+#include <utility>
 
 #include "opentelemetry/common/key_value_iterable_view.h"
 #include "opentelemetry/sdk/metrics/view/attributes_processor.h"
